@@ -13,7 +13,7 @@ G_BEGIN_DECLS
 #define BTCTL_IS_CONTROLLER(obj)       (G_TYPE_CHECK_INSTANCE_TYPE (obj, BTCTL_TYPE_CONTROLLER))
 #define BTCTL_IS_CONTROLLER_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), BTCTL_TYPE_CONTROLLER))
 #define BTCTL_CONTROLLER_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), BTCTL_TYPE_CONTROLLER, BtctlControllerClass)
-
+#define BTCTL_ERROR (btctl_error_quark ())
 
 typedef struct _BtctlController BtctlController;
 typedef struct _BtctlControllerClass BtctlControllerClass;
@@ -39,7 +39,9 @@ struct _BtctlControllerClass
 };
 
 enum {
-	BTCTL_ERROR_NO_BLUETOOTH_DEVICE
+	BTCTL_ERROR_NO_BLUETOOTH_DEVICE,
+	BTCTL_ERROR_CONNECTION_FAILED,
+	BTCTL_ERROR_SERVICE_SEARCH_FAILED
 };
 
 /* Gtk housekeeping methods */
@@ -68,14 +70,14 @@ GQuark btctl_error_quark(void);
 
 gboolean btctl_controller_get_discoverable(BtctlController *bc, GError **err);
 void btctl_controller_set_discoverable(BtctlController *bc, gboolean discoverable, GError **err);
-void btctl_controller_discover_devices(BtctlController *bc);
+void btctl_controller_discover_devices(BtctlController *bc, GError **err);
 void btctl_controller_list_rfcomm_connections(BtctlController *bc);
 gint btctl_controller_establish_rfcomm_connection(BtctlController *bc,
 				       const gchar *bdstr, guint channel);
 gint btctl_controller_get_established_rfcomm_connection(BtctlController *bc,
 					     const gchar *bdstr,
 					     guint channel);
-void btctl_controller_scan_for_service(BtctlController *bc, const gchar *bdstr, guint clsid);
+gboolean btctl_controller_scan_for_service(BtctlController *bc, const gchar *bdstr, guint clsid, GError **err);
 void btctl_controller_cancel_discovery(BtctlController *bc);
 void btctl_controller_discover_async (BtctlController *bc);
 gboolean btctl_controller_is_initialised (BtctlController *bc, GError **err);
