@@ -80,6 +80,8 @@ static gboolean cb_hci_data (BtctlDiscoverySource *source, gpointer user_data);
 static void name_request (BtctlController *bc, bdaddr_t *bdaddr);
 static void inquiry_result (BtctlController *bc, int dd, unsigned char *buf,
         int len);
+static void inquiry_result_with_rssi (BtctlController *bc, int dd,
+	unsigned char *buf, int len);
 static void conn_request (BtctlController *bc, int dd, unsigned char *buf,
         int len);
 static void conn_complete (BtctlController *bc, int dd, unsigned char *buf,
@@ -907,6 +909,36 @@ inquiry_result(BtctlController *bc, int dd, unsigned char *buf, int len)
 	}
 }
 
+static void
+inquiry_result_with_rssi(BtctlController *bc, int dd, unsigned char *buf, int len)
+{
+	inquiry_info_with_rssi *info;
+	uint8_t num;
+	char addr[18];
+	int i;
+	uint32_t devclass;
+	bdaddr_t *nb;
+
+	num = buf[0];
+
+	for (i = 0; i < num; i++) {
+		info = (void *) (buf + (sizeof(*info) * i) + 1);
+		ba2str(&info->bdaddr, addr);
+		devclass = (uint32_t)(info->dev_class[2]) << 16 |
+			(uint32_t)(info->dev_class[1]) << 8 |
+			(uint32_t)(info->dev_class[0]);
+		g_message ("inquiry_result_with_rssi:\tbdaddr %s class %x", addr, devclass);
+		nb = g_new0(bdaddr_t, 1);
+		bacpy(nb, &info->bdaddr);
+		/* inquiry can generate multiple identical results, so make
+		 * sure we only log each once */
+		if (! g_slist_find_custom (bc->found, (gpointer)nb, bdaddr_comparator)) {
+			bc->found = g_slist_append (bc->found, (gpointer)nb);
+			btctl_controller_got_device (bc, addr, devclass);
+		}
+	}
+}
+
 static void
 conn_request(BtctlController *bc, int dd, unsigned char *buf, int len)
 {
@@ -1029,6 +1061,9 @@ cb_hci_data (BtctlDiscoverySource *source, gpointer user_data)
 	case EVT_INQUIRY_RESULT:
 		inquiry_result(bc, source->fd.fd, ptr, len);
 		break;
+	case EVT_INQUIRY_RESULT_WITH_RSSI:
+		inquiry_result_with_rssi(bc, source->fd.fd, ptr,len);
+		break;
 	case EVT_INQUIRY_COMPLETE:
 		inquiry_complete(bc, source->fd.fd);
 		break;
