@@ -189,6 +189,10 @@ obex_event (obex_t *handle, obex_object_t *obj,
             invoke_callback (s, event, 0, obj);
             break;
 
+	case OBEX_EV_REQCHECK:
+	    /* g_warning ("OBEX_EV_REQCHECK"); */
+	    break;
+
         default:
             g_warning ("Unhandled OBEX event %d", event);
             break;
